@@ -85,7 +85,13 @@ def load_configuration(config_module_name):
     return config
 
 
-def setup(config, specs_dir=None, templates_dir=None, resources_dir=None):
+def setup(
+    config,
+    specs_dir=None,
+    sandbox_dir=None,
+    templates_dir=None,
+    resources_dir=None
+):
     """
     Performs common setup tasks. Requires a configuration object (see
     `load_configuration`). Supplies defaults for specifications,
@@ -100,7 +106,10 @@ def setup(config, specs_dir=None, templates_dir=None, resources_dir=None):
     if specs_dir is None:
         specs_dir = os.path.join(config.BASE_DIR, "specs")
 
-    load.set_specs_dir(specs_dir)
+    if sandbox_dir is None:
+        sandbox_dir = os.path.join(config.BASE_DIR, "sandboxes")
+
+    load.setup(specs_dir, sandbox_dir)
 
     # Set up reports system based on templates and resources directories
     # from config
@@ -601,6 +610,10 @@ def launch_job(
     done = False
     try:
         logging.log(f"This is potluck version {__version__}")
+        logging.log(
+            f"Running in Python {sys.version.split()[0]} at"
+            f" '{sys.executable}'"
+        )
 
         tasks_data = load_tasks_data(config)
 
