@@ -541,8 +541,10 @@ def harness_descriptions(
 ):
     """
     Extracts descriptions of a test harness from its docstring and
-    formats them using the given function name, returning a description
-    4-tuple of strings.
+    formats them using the given function name, topic arguments
+    representation, details arguments representation, and description of
+    what is captured by the test. Returns a description 4-tuple of
+    strings.
     """
     hdesc = description_templates_from_docstring(test_harness)
 
@@ -569,7 +571,7 @@ def harness_descriptions(
         topic_args_repr,
         details_args_repr,
     ]
-    result = (
+    result = tuple(
         part.format(fname=fname, args=args_repr, captured=what_is_captured)
         for part, args_repr in zip(hdesc, args_for_parts)
     )
