@@ -5,6 +5,7 @@ render.py
 """
 
 import os
+import sys
 import json
 
 import markdown
@@ -20,6 +21,15 @@ from . import html_tools
 from . import time_utils
 
 
+#-------------------#
+# 2/3 compatibility #
+#-------------------#
+
+if sys.version_info[0] < 3:
+    ModuleNotFound_or_Import_Error = ImportError
+else:
+    ModuleNotFound_or_Import_Error = ModuleNotFoundError
+
 #---------#
 # Globals #
 #---------#
@@ -175,7 +185,7 @@ def render_markdown(md_source):
     try:
         import pymdownx # noqa F401
         x = 'pymdownx.extra'
-    except ModuleNotFoundError:
+    except ModuleNotFound_or_Import_Error:
         x = 'extra'
 
     return markdown.markdown(md_source, extensions=[x])
@@ -543,10 +553,11 @@ def render_rubric_row(taskid, row, blank=False):
         topic_class += " no_details"
         details_node = ''
 
+    rowid = row.get("id", "")
     contents += (
         '<div {}class="{}" tabindex="0">\n{}\n{}\n{}\n{}\n</div>'
     ).format(
-        'id="{}" '.format(row.get("id", "")),
+        'id="{}" '.format(rowid) if rowid else '',
         topic_class,
         html_tools.build_status_indicator(row["status"]),
         "<span class='sr-only'>{}</span>".format(row["status"]),
@@ -587,6 +598,7 @@ def render_rubric_row(taskid, row, blank=False):
 
     contents += subtable
 
+    # CSS classes for the rubric row
     classes = [
         "rubric_row",
         html_tools.status_css_class(row["status"])
@@ -594,6 +606,9 @@ def render_rubric_row(taskid, row, blank=False):
         "tag-{k}-{v}".format(k=k, v=v)
         for (k, v) in row.get("tags", {}).items()
     ]
+    # CSS class 'goal_category' for non-ID's items
+    if rowid == '':
+        classes.append("goal_category")
     return '<div class="{}">{}</div>'.format(
         ' '.join(classes),
         contents
